@@ -9,12 +9,12 @@ import qdarkstyle
 import requests
 import math
 import imgviz
-from multiprocessing import Process
 
 from qtpy import QtCore
 from qtpy.QtCore import Qt
 from qtpy import QtGui
 from qtpy import QtWidgets
+from qtpy import uic
 
 from itertools import zip_longest
 
@@ -33,7 +33,6 @@ from enhancedlabelme.logger import logger
 from enhancedlabelme.shape import Shape
 from enhancedlabelme.widgets import BrightnessContrastDialog
 from enhancedlabelme.widgets import Canvas
-from enhancedlabelme.widgets import ColorDialog
 from enhancedlabelme.widgets import LabelDialog
 from enhancedlabelme.widgets import LabelListWidget
 from enhancedlabelme.widgets import LabelListWidgetItem
@@ -55,6 +54,106 @@ from enhancedlabelme.widgets import ZoomWidget
 LABEL_COLORMAP = imgviz.label_colormap(value=200)
 os.environ['QT_API'] = 'pyqt5'
 
+class PenStyleWindow(QtWidgets.QDialog):
+    def __init__(self, parent=None):
+        super(PenStyleWindow, self).__init__(parent)
+        self.penColor = parent.canvas.penColor
+        self.penThickness = parent.canvas.penThickness
+        self.penStyle = parent.canvas.penStyle
+        self.initUI(parent)
+
+    def initUI(self, parent):
+        option_ui = 'enhancedlabelme/ui/penstylewindow.ui'
+        uic.loadUi(option_ui, self)
+        
+        # Load current style
+        self.horizontalSlider_thickness.setSliderPosition(self.penThickness * 10)
+        
+        if self.penColor == QtCore.Qt.black:
+            self.comboBox_color.setCurrentIndex(0)
+        elif self.penColor == QtCore.Qt.white:
+            self.comboBox_color.setCurrentIndex(1)
+        elif self.penColor == QtCore.Qt.gray:
+            self.comboBox_color.setCurrentIndex(2)
+        elif self.penColor == QtCore.Qt.red:
+            self.comboBox_color.setCurrentIndex(3)
+        elif self.penColor == QtCore.Qt.yellow:
+            self.comboBox_color.setCurrentIndex(4)
+        elif self.penColor == QtCore.Qt.green:
+            self.comboBox_color.setCurrentIndex(5)
+        elif self.penColor == QtCore.Qt.blue:
+            self.comboBox_color.setCurrentIndex(6)
+        elif self.penColor == QtCore.Qt.cyan:
+            self.comboBox_color.setCurrentIndex(7)
+        elif self.penColor == QtCore.Qt.magneta:
+            self.comboBox_color.setCurrentIndex(8)        
+        
+        if self.penStyle == QtCore.Qt.SolidLine:
+            self.comboBox_shape.setCurrentIndex(0)
+        elif self.penStyle == QtCore.Qt.DashLine:
+            self.comboBox_shape.setCurrentIndex(1)
+        elif self.penStyle == QtCore.Qt.DotLine:
+            self.comboBox_shape.setCurrentIndex(2)     
+        
+        self.comboBox_shape.activated[str].connect(self.saveShape)
+        self.comboBox_color.activated[str].connect(self.saveColor)
+        self.horizontalSlider_thickness.valueChanged.connect(self.saveThickness)
+        self.buttonBox_cross.accepted.connect(functools.partial(self.saveSettings, parent))
+        self.setWindowTitle('Cross-line Style Configuration')
+        self.show()
+        
+    def paintEvent(self, event):
+        qp = QtGui.QPainter()
+        qp.begin(self)
+        self.drawLines(qp)
+        qp.end()
+        
+    def drawLines(self, qp):
+        pen = QtGui.QPen(self.penColor, self.penThickness, self.penStyle)
+        qp.setPen(pen)
+        qp.drawLine(50, 160, 250, 160)
+        
+    def saveShape(self, value):
+        if value == 'SolidLine':
+            self.penStyle = QtCore.Qt.SolidLine
+        elif value == 'DashLine':
+            self.penStyle = QtCore.Qt.DashLine
+        elif value == 'DotLine':
+            self.penStyle = QtCore.Qt.DotLine
+        self.repaint()
+        
+    def saveColor(self, value):
+        if value == 'Black':
+            self.penColor = QtCore.Qt.black
+        elif value == 'White':
+            self.penColor = QtCore.Qt.white
+        elif value == 'gray':
+            self.penColor = QtCore.Qt.gray
+        elif value == 'Red':
+            self.penColor = QtCore.Qt.red
+        elif value == 'Yellow':
+            self.penColor = QtCore.Qt.yellow
+        elif value == 'Green':
+            self.penColor = QtCore.Qt.green
+        elif value == 'Blue':
+            self.penColor = QtCore.Qt.blue
+        elif value == 'Cyan':
+            self.penColor = QtCore.Qt.cyan
+        elif value == 'Pink':
+            self.penColor = QtCore.Qt.magneta
+        self.repaint()
+        
+    def saveThickness(self, value):
+        value = float(value / 10)
+        self.penThickness = value
+        self.repaint()
+    
+    def saveSettings(self, parent):
+        parent.canvas.penColor = self.penColor
+        parent.canvas.penThickness = self.penThickness 
+        parent.canvas.penStyle = self.penStyle
+        
+        
 class MainWindow(QtWidgets.QMainWindow):
 
     FIT_WINDOW, FIT_WIDTH, MANUAL_ZOOM = 0, 1, 2
@@ -103,6 +202,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.lastOpenDir = None
 
         self.loadTime = str(datetime.now())
+        self.polygon = False
 
         self.flag_dock = self.flag_widget = None
         self.flag_dock = QtWidgets.QDockWidget(self.tr('Flags'), self)
@@ -166,7 +266,6 @@ class MainWindow(QtWidgets.QMainWindow):
 
         self.zoomWidget = ZoomWidget()
         self.setAcceptDrops(True)
-        self.colorDialog = ColorDialog(parent=self)
 
         self.canvas = self.labelList.canvas = Canvas(
             epsilon=self._config['epsilon'],
@@ -373,12 +472,9 @@ class MainWindow(QtWidgets.QMainWindow):
                       self.tr('Undo last add and edit of shape'),
                       enabled=False)
 
-        hideAll = action(self.tr('&Hide\nPolygons'),
-                         functools.partial(self.togglePolygons, False),
-                         icon='eye', tip=self.tr('Hide all polygons'),
-                         enabled=False)
-        showAll = action(self.tr('&Show\nPolygons'),
-                         functools.partial(self.togglePolygons, True),
+        showAll = action(self.tr('&Hide/Show\nPolygons'),
+                         self.togglePolygons,
+                         shortcuts['show_polygon'],
                          icon='eye', tip=self.tr('Show all polygons'),
                          enabled=False)
 
@@ -444,6 +540,9 @@ class MainWindow(QtWidgets.QMainWindow):
                            tip=self.tr('Show cross hair around the mouse cursor'),
                            checkable=True, checked=self._config['cross_hair'],)
         crossHair.setChecked(self._config['cross_hair'])
+        crossStyle = action(self.tr('&Cross-line Style'), self.crossStyleSetting,
+                             icon='edit', tip=self.tr(u'Configure Cross-line Style'))
+        
         darkMode = action(self.tr('&Dark Theme'), self.darkModeToggle, icon='dark',
                 tip=self.tr('Toggle dark theme'), checkable=True, checked=self._config['dark_mode'],)
 
@@ -513,6 +612,7 @@ class MainWindow(QtWidgets.QMainWindow):
             fileMenuActions=(open_, opendir, save, saveAs, close, quit),
             tool=(),
             crossHair=crossHair,
+            crossStyle=crossStyle,
             darkMode=darkMode,
             # XXX: need to add some actions here to activate the shortcut
             editMenu=(
@@ -555,7 +655,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 editMode,
                 brightnessContrast,
             ),
-            onShapesPresent=(saveAs, hideAll, showAll),
+            onShapesPresent=(saveAs, showAll),
         )
 
         self.canvas.edgeSelected.connect(self.canvasShapeEdgeSelected)
@@ -603,10 +703,10 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.file_dock.toggleViewAction(),
                 None,
                 crossHair,
+                crossStyle,
                 None,
                 fill_drawing,
                 None,
-                hideAll,
                 showAll,
                 None,
                 zoomIn,
@@ -869,6 +969,10 @@ class MainWindow(QtWidgets.QMainWindow):
         return QtWidgets.QMessageBox.about(
             self, 'About', '\n<Version %s>\n%s'%(__version__, "Modified by LilactheGreat"))
         
+    def crossStyleSetting(self):
+        psw = PenStyleWindow(self)
+        #self.canvas.penStyle, self.canvas.penThickness, self.canvas.penColor = psw.saveSettings(self)
+        
     def readme(self):
         import platform, subprocess
         if platform.system() == 'Darwin':       # macOS
@@ -1368,13 +1472,13 @@ class MainWindow(QtWidgets.QMainWindow):
         self.zoom_values[self.filename] = (self.zoomMode, value)
 
     def addZoom(self, increment=1.1):
+        self.setZoom(self.zoomWidget.value() * increment)
         zoom_value = self.zoomWidget.value() * increment
         if increment > 1:
             zoom_value = math.ceil(zoom_value)
         else:
             zoom_value = math.floor(zoom_value)
         self.setZoom(zoom_value)
-
     def zoomRequest(self, delta, pos):
         canvas_width_old = self.canvas.width()
         units = 1.1
@@ -1434,9 +1538,13 @@ class MainWindow(QtWidgets.QMainWindow):
         contrast = dialog.slider_contrast.value()
         self.brightnessContrast_values[self.filename] = (brightness, contrast)
 
-    def togglePolygons(self, value):
+    def togglePolygons(self):
+        if self.polygon:
+            self.polygon = False
+        else:
+            self.polygon = True
         for item in self.labelList:
-            item.setCheckState(Qt.Checked if value else Qt.Unchecked)
+            item.setCheckState(Qt.Checked if self.polygon else Qt.Unchecked)
 
     def loadFile(self, filename=None):
         """Load the specified file, or the last opened file if None."""
