@@ -87,6 +87,9 @@ class Canvas(QtWidgets.QWidget):
         self.cross = False
         self.posc = None
         self.dialog = False
+        self.penStyle = QtCore.Qt.DashLine
+        self.penThickness = 1.0
+        self.penColor = QtCore.Qt.black
 
     def fillDrawing(self):
         return self._fill_drawing
@@ -562,7 +565,7 @@ class Canvas(QtWidgets.QWidget):
                 self.cross = True
             try:
                 if self.cross == True and self.pixmap and self.dialog == False:
-                    p.setPen(QtGui.QPen(QtCore.Qt.black, 0.9, QtCore.Qt.DashLine))
+                    p.setPen(QtGui.QPen(self.penColor, self.penThickness, self.penStyle))
                     p.drawLine(self.posc.x(), self.pixmap.height(), self.posc.x(), 0)
                     p.drawLine(0, self.posc.y(), self.pixmap.width(), self.posc.y())
                     self.update()
@@ -743,6 +746,7 @@ class Canvas(QtWidgets.QWidget):
         if clear_shapes:
             self.shapes = []
         self.repaint()
+        
     def loadShapes(self, shapes, replace=True):
         if replace:
             self.shapes = list(shapes)
